import { select, descending } from 'd3';
import { viz } from './viz';
import { data } from '@curran/un-population-estimates-2024';

export const main = (container) => {
  const width = container.clientWidth;
  const height = container.clientHeight;

  const populationColumn =
    'Total Population, as of 1 January (thousands)';
  const nameColumn = 'Region, subregion, country or area *';
  const n = 10;

  const formattedData = data
    .filter((d) => d['Type'] == 'Country/Area')
    .sort((a, b) =>
      descending(a[populationColumn], b[populationColumn]),
    )
    .slice(0, n);

  const svg = select(container)
    .selectAll('svg')
    .data([null])
    .join('svg')
    .attr('width', width)
    .attr('height', height);

  viz(svg, {
    data: formattedData,
    width,
    height,
    marginTop: 20,
    marginBottom: 56,
    marginLeft: 74,
    marginRight: 20,
    xValue: (d) => d[nameColumn],
    yValue: (d) => d[populationColumn],
    xAxisLabelText: 'Country',
    yAxisLabelText: 'Population',
    xAxisLabelOffset: 38,
    yAxisLabelOffset: 17,
    innerRectFill: '#E8E8E8',
    circleRadius: 153 / 20,
    circleOpacity: 629 / 1000,
    barGap: 0.15,
  });
};
