import { scaleLinear, scaleBand, axisLeft, max } from 'd3';
import {
  xAxis,
  yAxis,
  xAxisLabel,
  yAxisLabel,
} from '@curran/axis-labels';

export const viz = (
  svg,
  {
    data,
    xValue,
    xAxisLabelText,
    xAxisLabelOffset,
    yValue,
    yAxisLabelText,
    yAxisLabelOffset,
    marginLeft,
    marginTop,
    marginRight,
    marginBottom,
    width,
    height,
    innerRectFill,
    circleRadius,
    circleOpacity,
    barGap,
  },
) => {
  const xScale = scaleBand(data.map(xValue), [
    marginLeft,
    width - marginRight,
  ]).padding(barGap);
  const yScale = scaleLinear(
    [0, max(data, yValue)],
    [height - marginBottom, marginTop],
  );

  const innerWidth = width - marginLeft - marginRight;
  const innerHeight = height - marginTop - marginBottom;

  svg
    .selectAll('rect')
    .data([null])
    .join('rect')
    .attr('x', marginLeft)
    .attr('y', marginTop)
    .attr('width', innerWidth)
    .attr('height', innerHeight)
    .attr('fill', innerRectFill);

  // Axes
  xAxis(svg, { height, marginBottom, xScale });
  yAxis(svg, { marginLeft, yScale });

  // Axis Labels
  xAxisLabel(svg, {
    xAxisLabelText,
    width,
    height,
    marginBottom,
    xAxisLabelOffset,
  });
  yAxisLabel(svg, {
    yAxisLabelText,
    yAxisLabelOffset,
    height,
  });

  // Circles
  svg
    .selectAll('rect.mark')
    .data(data)
    .join('rect')
    .attr('class', 'mark')
    .attr('x', (d) => xScale(xValue(d)))
    .attr('y', (d) => yScale(yValue(d)))
    .attr('width', xScale.bandwidth())
    .attr('height', (d) => yScale(0) - yScale(yValue(d)));
};
